@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,10 +7,12 @@
 #ifndef AKONADISEARCHDEBUGSEARCHPATHCOMBOBOX_H
 #define AKONADISEARCHDEBUGSEARCHPATHCOMBOBOX_H
 
-#include <QComboBox>
 #include "search_debug_export.h"
-namespace Akonadi {
-namespace Search {
+#include <QComboBox>
+namespace Akonadi
+{
+namespace Search
+{
 /**
  * @brief The AkonadiSearchDebugSearchPathComboBox class
  * @author Laurent Montel <montel@kde.org>
@@ -20,19 +22,14 @@ class AKONADI_SEARCH_DEBUG_EXPORT AkonadiSearchDebugSearchPathComboBox : public
     Q_OBJECT
 public:
     explicit AkonadiSearchDebugSearchPathComboBox(QWidget *parent = nullptr);
-    enum SearchType {
-        Contacts = 0,
-        ContactCompleter,
-        Emails,
-        Notes,
-        Calendars
-    };
+    enum SearchType { Contacts = 0, ContactCompleter, Emails, Notes, Calendars };
     ~AkonadiSearchDebugSearchPathComboBox();
 
     QString searchPath();
 
     QString pathFromEnum(SearchType type);
     void setSearchType(SearchType type);
+
 private:
     QString defaultLocations(const QString &dbname);
     void initialize();
